@@ -14,50 +14,33 @@ from nowcasting_dataloader.xr_utils import re_order_dims
 
 logger = logging.getLogger(__name__)
 
-# Means computed with
-# nwp_ds = NWPDataSource(...)
-# nwp_ds.open()
-# mean = nwp_ds.data.isel(init_time=slice(0, 10)).mean(
-#     dim=['step', 'x', 'init_time', 'y']).compute()
+# Means and std computed with
+# nowcasting_dataset/scripts/compute_stats_from_batches.py
+# using v15 training batches on 2021-11-24.
 NWP_MEAN = {
-    "cdcb": 742.401,
-    "lcc": 66.756538,
-    "mcc": 157.74133,
-    "hcc": 15542.797,
-    "sde": 3.2133293,
-    "hcct": -5909.7021,
-    "dswrf": 49265.621,
-    "dlwrf": 167.16484,
-    "h": 1707.0344,
-    "t": 171.22368,
-    "r": 63.139393,
-    "dpt": 158.05571,
-    "vis": 16480.631,
-    "si10": -5607.0537,
-    "wdir10": 151.85562,
-    "prmsl": 52296.281,
-    "prate": 975.62311,
+    "t": 285.7799539185846,
+    "dswrf": 294.6696933986283,
+    "prate": 3.6078121378638696e-05,
+    "r": 75.57106712435926,
+    "sde": 0.0024915961594965614,
+    "si10": 4.931356852411006,
+    "vis": 22321.762918384553,
+    "lcc": 47.90454236572895,
+    "mcc": 44.22781694449808,
+    "hcc": 32.87577371914454,
 }
 
-
 NWP_STD = {
-    "cdcb": 1437.9733,
-    "lcc": 32.845642,
-    "mcc": 122.90843,
-    "hcc": 22072.18,
-    "sde": 4.2809649,
-    "hcct": 13865.189,
-    "dswrf": 50599.918,
-    "dlwrf": 165.04289,
-    "h": 1566.2006,
-    "t": 118.57211,
-    "r": 35.996311,
-    "dpt": 128.49652,
-    "vis": 22340.301,
-    "si10": 13388.914,
-    "wdir10": 153.62816,
-    "prmsl": 50509.055,
-    "prate": 1263.6071,
+    "t": 5.017000766747606,
+    "dswrf": 233.1834250473355,
+    "prate": 0.00021690701537950742,
+    "r": 15.705370079694358,
+    "sde": 0.07560040052148084,
+    "si10": 2.664583614352396,
+    "vis": 12963.802514945439,
+    "lcc": 40.06675870700349,
+    "mcc": 41.927221148316384,
+    "hcc": 39.05157559763763,
 }
 
 
